@@ -4,23 +4,24 @@
 #include <QWidget>
 #include "video.h"
 #include "loadingwidget.h"
-#include "ListModel.h"
+#include "playlistmodel.h"
 
 class VideoAreaWidget : public QWidget {
 
     Q_OBJECT
 
 public:
-    VideoAreaWidget(QWidget *parent);
+    VideoAreaWidget(QWidget *parent = 0);
     void setVideoWidget(QWidget *videoWidget);
     void setLoadingWidget(LoadingWidget *loadingWidget);
     void showLoading(Video* video);
     void showVideo();
     void showError(QString message);
     void clear();
-    void setListModel(ListModel *listModel) {
+    void setListModel(PlaylistModel *listModel) {
         this->listModel = listModel;
     }
+    void showSnapshotPreview(QPixmap pixmap);
 
 signals:
     void doubleClicked();
@@ -31,15 +32,17 @@ protected:
     void mousePressEvent(QMouseEvent *event);
     void dragEnterEvent(QDragEnterEvent *event);
     void dropEvent(QDropEvent *event);
-    void mouseMoveEvent(QMouseEvent *event);
-    void leaveEvent(QMouseEvent *event);
+
+private slots:
+    void hideSnapshotPreview();
 
 private:
     QStackedLayout *stackedLayout;
     QWidget *videoWidget;
     LoadingWidget *loadingWidget;
-    ListModel *listModel;
+    PlaylistModel *listModel;
     QLabel *messageLabel;
+    QLabel *snapshotPreview;
 
 };
 
